Bootstrap Lightbox
========

A lightbox module for Bootstrap that supports images, YouTube videos, and galleries - built around Bootstrap's Modal plugin.

See the github page for docs: http://ashleydw.github.io/lightbox

Contributing
----
Instead of modifying the /dist/*.js JavaScript files directly, you should instead modify the ekko-lightbox.js file and run the grunt task.

Copyright and license
----

Code released under [the MIT license](https://github.com/ashleydw/lightbox/blob/master/LICENSE).
